# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class QueryDesks(BaseModel):
    desks: Optional["QueryDesksDesks"]


class QueryDesksDesks(BaseModel):
    results: Optional[list["QueryDesksDesksResults"]]


class QueryDesksDesksResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryDesksDesksResultsOwner"
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["QueryDesksDesksResultsBureau"]
    agent_count: Optional[int] = Field(alias="agentCount")


class QueryDesksDesksResultsOwner(BaseModel):
    id: str


class QueryDesksDesksResultsBureau(BaseModel):
    id: str


QueryDesks.model_rebuild()
QueryDesksDesks.model_rebuild()
QueryDesksDesksResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteDesk(BaseModel):
    delete_desk: Optional["DeleteDeskDeleteDesk"] = Field(alias="deleteDesk")


class DeleteDeskDeleteDesk(BaseModel):
    id: str
    state: EntityState


DeleteDesk.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityOwners, EntityState


class PublishSkills(BaseModel):
    publish_skills: Optional["PublishSkillsPublishSkills"] = Field(
        alias="publishSkills"
    )


class PublishSkillsPublishSkills(BaseModel):
    skills: Optional[list["PublishSkillsPublishSkillsSkills"]]


class PublishSkillsPublishSkillsSkills(BaseModel):
    id: str
    name: str
    state: EntityState
    identifier: Optional[str]
    skill_owner: Optional[EntityOwners] = Field(alias="skillOwner")
    arguments: Optional[list["PublishSkillsPublishSkillsSkillsArguments"]]
    text: str


class PublishSkillsPublishSkillsSkillsArguments(BaseModel):
    name: str
    description: Optional[str]
    required: Optional[bool]


PublishSkills.model_rebuild()
PublishSkillsPublishSkills.model_rebuild()
PublishSkillsPublishSkillsSkills.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteDesks(BaseModel):
    delete_desks: Optional[list[Optional["DeleteDesksDeleteDesks"]]] = Field(
        alias="deleteDesks"
    )


class DeleteDesksDeleteDesks(BaseModel):
    id: str
    state: EntityState


DeleteDesks.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class AddAgentsToDesk(BaseModel):
    add_agents_to_desk: Optional["AddAgentsToDeskAddAgentsToDesk"] = Field(
        alias="addAgentsToDesk"
    )


class AddAgentsToDeskAddAgentsToDesk(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["AddAgentsToDeskAddAgentsToDeskBureau"]
    agents: Optional[list[Optional["AddAgentsToDeskAddAgentsToDeskAgents"]]]
    agent_count: Optional[int] = Field(alias="agentCount")


class AddAgentsToDeskAddAgentsToDeskBureau(BaseModel):
    id: str


class AddAgentsToDeskAddAgentsToDeskAgents(BaseModel):
    id: str
    name: str


AddAgentsToDesk.model_rebuild()
AddAgentsToDeskAddAgentsToDesk.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class AddDesksToBureau(BaseModel):
    add_desks_to_bureau: Optional["AddDesksToBureauAddDesksToBureau"] = Field(
        alias="addDesksToBureau"
    )


class AddDesksToBureauAddDesksToBureau(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    mission: Optional[str]
    directives: Optional[str]
    desks: Optional[list[Optional["AddDesksToBureauAddDesksToBureauDesks"]]]
    desk_count: Optional[int] = Field(alias="deskCount")


class AddDesksToBureauAddDesksToBureauDesks(BaseModel):
    id: str
    name: str


AddDesksToBureau.model_rebuild()
AddDesksToBureauAddDesksToBureau.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class RemoveDesksFromBureau(BaseModel):
    remove_desks_from_bureau: Optional["RemoveDesksFromBureauRemoveDesksFromBureau"] = (
        Field(alias="removeDesksFromBureau")
    )


class RemoveDesksFromBureauRemoveDesksFromBureau(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    mission: Optional[str]
    directives: Optional[str]
    desks: Optional[list[Optional["RemoveDesksFromBureauRemoveDesksFromBureauDesks"]]]
    desk_count: Optional[int] = Field(alias="deskCount")


class RemoveDesksFromBureauRemoveDesksFromBureauDesks(BaseModel):
    id: str
    name: str


RemoveDesksFromBureau.model_rebuild()
RemoveDesksFromBureauRemoveDesksFromBureau.model_rebuild()
